Module execution

Module execution 

Components for initialising multi-exchange execution, routing ExecutionRequests and other execution logic.

Modules

builder
Provides an execution manager builder for ergonomically initialising multiple execution links to mock and live exchanges.
error
Provides an error type that represents all errors that are generated by an execution link.
manager
Per-exchange execution manager that actions order requests from the Engine and forwards back responses.
request
Defines an ExecutionRequest used by the Engine to communicate with an ExecutionManager.

Structs

Execution
Initialised ExecutionBuild.

Type Aliases

AccountStreamEvent
Convenient type alias that represents a reconnect::Event produced by the AccountEvent stream.